#!/usr/bin/python3

# Creates a dummy registry-file which just contains a specification for structure <struct> with structure-attribute <newattr> 

import sys
import getopt

def usage():
    print("""
USAGE: %s [ -m <MULTISEP> ] corpname struct newattr tmpdir 

Creates a dummy registry-file which just contains a specification for structure <struct> with structure-attribute <newattr> 
      
Options: 
   -m <MULTISEP>    iff a <MULTISEP>-character is supplied via option -m, the new attribute will be specified as MULTVALUE=yes MULTISEP=<MULTISEP> 
   -h               print this message""" % sys.argv[0])
    
def main():
    try:
       opts, args = getopt.getopt(sys.argv[1:], "hm:", ["help", "MULTISEP="])
    except getopt.GetoptError as err:
       # print help information and exit:
       print(err)  # will print something like "option -a not recognized"
       usage()
       sys.exit(2)
    optm = ""
    for o, a in opts:
       if o == "-m":
          optm = a
       elif o in ("-h", "--help"):
          usage()
          sys.exit()
       else:
          assert False, "unhandled option"
             
    corpname  = args[0]
    struct    = args[1]
    newattr   = args[2]
    tmpdir    = args[3]
     
    path = '%s/%s' % ( tmpdir, corpname );

    # constuct the ATTRIBUTE - depending on whether -m <MULTISEP> was supplied or not
    if (len(optm) != 0):
       multival = """ {
                MULTIVALUE "yes"
                MULTISEP "%s"
              }""" % optm
    else:
       multival = ""
    
    print("""VERTICAL "%s/add.vert"
PATH "%s/data"
ATTRIBUTE x
STRUCTURE %s {
     ATTRIBUTE %s %s
}
	""" % ( path, path, struct, newattr, multival) )


if __name__ == "__main__":
    main()
